@@ -1,13 +1,13 @@
 from PyQt4 import QtCore, QtGui
-from qtGUI.qtUImain import Ui_MainWindow
-from qtGUI.aboutDialog import Ui_aboutDialog
-from qtGUI.ProgressionDialog import ProgressionDialog
-from qtGUI.InstrumentDialog import InstrumentDialog
-from qtGUI.BlockDialog import BlockDialog
-from os import path
+from qtUImain import Ui_MainWindow
+from aboutDialog import Ui_aboutDialog
+from ProgressionDialog import ProgressionDialog
+from InstrumentDialog import InstrumentDialog
+from BlockDialog import BlockDialog
+from os import path, environ
+from mingus.core import diatonic
 import Progressions
 import Options
-from mingus.core import diatonic
 
 APP_NAME = "qtImproviser"
 APP_VERSION = "0.7"
@@ -295,9 +295,12 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		w.exec_()
 
 	def load_dialog(self):
+		h = "/home"
+		if 'HOME' in environ:
+			h = environ["HOME"]
 		f = QtGui.QFileDialog()
 		s = f.getOpenFileName(self, "Load improviser file.",
-				"/home", "Improviser files (*.imp)")
+				h, "Improviser files (*.imp)")
 		if s != "":
 			try:
 				o = Options.load_options_from_file(s, OptionClass())
@@ -319,9 +322,12 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 				self.set_status("Error: Couldn't open file for writing")
 
 	def save_dialog(self):
+		h = "/home"
+		if 'HOME' in environ:
+			h = environ["HOME"]
 		f = QtGui.QFileDialog()
 		s = str(f.getSaveFileName(self, "Save improviser file.",
-				"/home", "Improviser files (*.imp)"))
+				h, "Improviser files (*.imp)"))
 		if s != "":
 			if s[-4:].lower() != ".imp":
 				filename = s + ".imp"
